summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/sql/drivers/sqlite
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-08-09 22:25:47 -0500
committerTimothy Pearson <[email protected]>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/sql/drivers/sqlite
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/sql/drivers/sqlite')
-rw-r--r--tqtinterface/qt4/src/sql/drivers/sqlite/tqsql_sqlite.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/sql/drivers/sqlite/tqsql_sqlite.cpp b/tqtinterface/qt4/src/sql/drivers/sqlite/tqsql_sqlite.cpp
index c94f595..864c4c9 100644
--- a/tqtinterface/qt4/src/sql/drivers/sqlite/tqsql_sqlite.cpp
+++ b/tqtinterface/qt4/src/sql/drivers/sqlite/tqsql_sqlite.cpp
@@ -250,7 +250,7 @@ bool TQSTQLiteResult::reset (const TQString& query)
setActive(FALSE);
return FALSE;
}
// we have to fetch one row to tqfind out about
// the structure of the result set
d->skippedtqStatus = d->fetchNext(0);
setSelect(!d->rInf.isEmpty());
@@ -450,7 +450,7 @@ TQSqlIndex TQSTQLiteDriver::primaryIndex(const TQString &tblname) const
TQSqlQuery q = createQuery();
q.setForwardOnly(TRUE);
// finrst tqfind a UNITQUE INDEX
q.exec("PRAGMA index_list('" + tblname + "');");
TQString indexname;
while(q.next()) {
@@ -468,8 +468,8 @@ TQSqlIndex TQSTQLiteDriver::primaryIndex(const TQString &tblname) const
while(q.next()) {
TQString name = q.value(2).toString();
TQSqlVariant::Type type = TQSqlVariant::Invalid;
- if (rec.tqcontains(name))
- type = rec.tqfind(name).type();
+ if (rec.contains(name))
+ type = rec.find(name).type();
index.append(TQSqlField(name, type));
}
return index;
@@ -250,7 +250,7 @@ bool TQSTQLiteResult::reset (const TQString& query)
return FALSE;
}
- // we have to fetch one row to tqfind out about
+ // we have to fetch one row to find out about
// the structure of the result set
d->skippedtqStatus = d->fetchNext(0);
@@ -450,7 +450,7 @@ TQSqlIndex TQSTQLiteDriver::primaryIndex(const TQString &tblname) const
TQSqlQuery q = createQuery();
q.setForwardOnly(TRUE);
- // finrst tqfind a UNITQUE INDEX
+ // finrst find a UNITQUE INDEX
q.exec("PRAGMA index_list('" + tblname + "');");
TQString indexname;